translate.storage.ini

Package translate :: Package storage :: Module ini |
[hide private]
[frames] | no frames]

# Module ini

source code

Class that manages .ini files for translation

Note: A simple summary of what is permissible follows.

# a comment ; a comment

[Section] a = a string b : a string

Classes | [hide private]
| Dialect Base class for differentiating dialect options and functions
| DialectDefault
| DialectInno
| iniunit A INI file entry
| inifile An INI file

Functions | [hide private]
register_dialect(name, dialect) Register the dialect | source code

Variables | [hide private]
| _dialects = ``{``'``default``'``:` <class 'translate.storage.ini.DialectD`...``
| __package__ = ``'``translate.storage``'``

Imports: re, StringIO, INIConfig, base

Variables Details | [hide private]

  ### _dialects Value:
      {'default': <class 'translate.storage.ini.DialectDefault'>,
       'inno': <class 'translate.storage.ini.DialectInno'>}